#!/usr/bin/env python
from setuptools import setup
from setuptools.command.develop import develop
from setuptools.command.install import install

from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst')) as f:
    long_description = f.read()


def _post_install():
    """Post installation nltk corpus downloads."""
    import nltk
    nltk.download('words')
    nltk.download('stopwords')


class PostDevelop(develop):
    """Post-installation for development mode."""
    def run(self):
        develop.run(self)
        self.execute(_post_install, [], msg='Running post installation tasks')


class PostInstall(install):
    """Post-installation for production mode."""
    def run(self):
        install.run(self)
        self.execute(_post_install, [], msg='Running post installation tasks')


setup(
    # Name of the module
    name='gitsuggest',

    # Details
    version='0.0.10',
    description='A tool to suggest github repositories based on the' +
                ' repositories you have shown interest in.',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/csurfer/gitsuggest',

    # Author details
    author='Vishwas B Sharma',
    author_email='sharma.vishwas88@gmail.com',

    # License
    license='MIT',
    packages=['gitsuggest'],
    # NOTE: Package data to be included both in MANIFEST.in and here for sdist
    # to consider it to put in package (MANIFEST) and for setuptools to copy
    # it over (package_data).
    package_dir={'gitsuggest': 'gitsuggest'},
    package_data={'gitsuggest': ['res/*.template', 'gitlang/*.txt']},
    entry_points={
        'console_scripts': [
            'gitsuggest=gitsuggest.commandline:main',
        ],
    },
    test_suite='tests',
    keywords='github repository suggestion',
    classifiers=[
        # Intended Audience.
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        # License.
        'License :: OSI Approved :: MIT License',
        # Project maturity.
        'Development Status :: 3 - Alpha',
        # Operating Systems.
        'Operating System :: POSIX',
        # Supported Languages.
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        # Topic tags.
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    install_requires=['gensim', 'PyGithub', 'nltk', 'crayons'],
    cmdclass={
        'develop': PostDevelop,
        'install': PostInstall
    })



#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
gitsuggest.commandline
~~~~~~~~~~~~~~~~~~~~~~

This module contains code to use the GitSuggest as commandline.

Usage:

    >>> gitsuggest --help
    usage: gitsuggest [-h] username

    positional arguments:
      username    Github Username

    optional arguments:
      -h, --help  show this help message and exit
      --deep_dive  If added considers repositories starred by users you follow
                   along with repositories you have starred. Is significantly
                   slower.

    >>> gitsuggest <username>
    # Asks for password input in a secure way to fetch suggested repositories
    # for the authenticated user.
"""
import argparse
import getpass
import webbrowser

import crayons
import github

from .suggest import GitSuggest
from .utilities import ReposToHTML


def main():
    """Starting point for the program execution."""

    # Create command line parser.
    parser = argparse.ArgumentParser()

    # Adding command line arguments.
    parser.add_argument('username',
                        help='Github Username',
                        default=None)

    parser.add_argument('--deep_dive',
                        help=' '.join([
                            'If added considers repositories starred by users',
                            'you follow along with repositories you have',
                            'starred. Is significantly slower.'
                        ]),
                        action='store_true',
                        default=False)

    # Parse command line arguments.
    arguments = parser.parse_args()

    if arguments.username is None:
        parser.print_help()
        return

    print('')
    print(crayons.white(
        'Authentication (with password) have higher rate limits.'))
    print(crayons.white(
        'Skipping password might cause failure due to rate limit.'))
    print('')

    password = getpass.getpass(crayons.blue(
        'Enter password (to skip press enter without entering anything): ',
        bold=True))

    try:
        gs = GitSuggest(username=arguments.username,
                        password=password,
                        token=None,
                        deep_dive=arguments.deep_dive)
    except github.BadCredentialsException:
        print('')
        print(crayons.red(
            'Incorrect password provided, to skip password enter nothing.',
            bold=True))
        exit()

    print('')
    print(crayons.green('Suggestions generated !'))

    repos = list(gs.get_suggested_repositories())
    r2h = ReposToHTML(repos)

    file_name = '/tmp/gitresults.html'
    r2h.to_html(file_name)

    webbrowser.open_new('file://' + file_name)


if __name__ == '__main__':
    main()
